pub struct BlockingTaskPool { /* private fields */ }rayon only.Expand description
Used to execute blocking tasks on a rayon threadpool from within a tokio runtime.
This is a dedicated threadpool for blocking tasks which are CPU bound. RPC calls that perform blocking IO (disk lookups) are not executed on this pool but on the tokio runtime’s blocking pool, which performs poorly with CPU bound tasks (see https://ryhl.io/blog/async-what-is-blocking/). Once the tokio blocking pool is saturated it is converted into a queue, blocking tasks could then interfere with the queue and block other RPC calls.
See also tokio-docs for more information.
Implementations
Sourceimpl BlockingTaskPool
impl BlockingTaskPool
Sourcepub fn build() -> Result<Self, ThreadPoolBuildError>
pub fn build() -> Result<Self, ThreadPoolBuildError>
Convenience function to build a new threadpool with the default configuration.
Uses rayon::ThreadPoolBuilder::build defaults.
If a different stack size or other parameters are needed, they can be configured via
[rayon::ThreadPoolBuilder] returned by Self::builder.
Sourcepub fn spawn<F, R>(&self, func: F) -> BlockingTaskHandle<R> ⓘ
pub fn spawn<F, R>(&self, func: F) -> BlockingTaskHandle<R> ⓘ
Asynchronous wrapper around Rayon’s
ThreadPool::spawn.
Runs a function on the configured threadpool, returning a future that resolves with the function’s return value.
If the function panics, the future will resolve to an error.
Sourcepub fn spawn_fifo<F, R>(&self, func: F) -> BlockingTaskHandle<R> ⓘ
pub fn spawn_fifo<F, R>(&self, func: F) -> BlockingTaskHandle<R> ⓘ
Asynchronous wrapper around Rayon’s
ThreadPool::spawn_fifo.
Runs a function on the configured threadpool, returning a future that resolves with the function’s return value.
If the function panics, the future will resolve to an error.