pub struct TaskManager { /* private fields */ }Expand description
Monitors critical tasks for panics and manages graceful shutdown.
The main purpose of this type is to be able to monitor if a critical task panicked, for
diagnostic purposes, since tokio tasks essentially fail silently. Therefore, this type is a
Future that resolves with the name of the panicked task. See Runtime::spawn_critical_task.
Automatically spawned as a background task when building a Runtime. Use
Runtime::take_task_manager_handle to extract the join handle if you need to poll for
panic errors directly.
Implementations
Sourceimpl TaskManager
impl TaskManager
Sourcepub fn graceful_shutdown(self)
pub fn graceful_shutdown(self)
Fires the shutdown signal and awaits until all tasks are shutdown.
Sourcepub fn graceful_shutdown_with_timeout(self, timeout: Duration) -> bool
pub fn graceful_shutdown_with_timeout(self, timeout: Duration) -> bool
Fires the shutdown signal and awaits until all tasks are shutdown.
Returns true if all tasks were shutdown before the timeout elapsed.