thread_native_id

Function thread_native_id 

pub fn thread_native_id() -> u64
Returns current thread id, which is the current OS’s native handle. It may or may not be equal or even related to rust’s thread id, there is absolutely no guarantee for that.

Usage

use thread_priority::thread_native_id;

assert!(thread_native_id() > 0);