Enum RealtimeThreadSchedulePolicy
pub enum RealtimeThreadSchedulePolicy {
Fifo,
RoundRobin,
Deadline,
}Available on Linux or macOS or iOS or DragonFly BSD or FreeBSD or OpenBSD or
target_os=vxworks or NetBSD or Android or WebAssembly only.Expand description
The following “real-time” policies are also supported, for special time-critical applications that need precise control over the way in which runnable processes are selected for execution
Variants
Fifo
A first-in, first-out policy
RoundRobin
A round-robin policy
Deadline
Available on (Linux or Android) and non-WebAssembly only.
A deadline policy. Note, due to Linux expecting a pid_t and not a pthread_t, the given ThreadId will be interpreted as a pid_t. This policy is NOT POSIX-compatible, so we only include it for linux targets.