Struct DeadlineFlags
pub struct DeadlineFlags(/* private fields */);target_os=vxworks or NetBSD or Android or WebAssembly only.Expand description
Flags for controlling Deadline scheduling behavior.
Implementations
impl DeadlineFlags
impl DeadlineFlags
pub const RESET_ON_FORK: DeadlineFlags
pub const RESET_ON_FORK: DeadlineFlags
Children created by [libc::fork] will not inherit privileged
scheduling policies.
pub const RECLAIM: DeadlineFlags
pub const RECLAIM: DeadlineFlags
The thread may reclaim bandwidth that is unused by another realtime thread.
pub const DEADLINE_OVERRUN: DeadlineFlags
pub const DEADLINE_OVERRUN: DeadlineFlags
Allows a task to get informed about runtime overruns through the delivery of SIGXCPU signals.
impl DeadlineFlags
impl DeadlineFlags
pub const fn empty() -> DeadlineFlags
pub const fn empty() -> DeadlineFlags
Get a flags value with all bits unset.
pub const fn all() -> DeadlineFlags
pub const fn all() -> DeadlineFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<DeadlineFlags>
pub const fn from_bits(bits: u64) -> Option<DeadlineFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> DeadlineFlags
pub const fn from_bits_truncate(bits: u64) -> DeadlineFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> DeadlineFlags
pub const fn from_bits_retain(bits: u64) -> DeadlineFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<DeadlineFlags>
pub fn from_name(name: &str) -> Option<DeadlineFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: DeadlineFlags) -> bool
pub const fn intersects(&self, other: DeadlineFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
pub const fn contains(&self, other: DeadlineFlags) -> bool
pub const fn contains(&self, other: DeadlineFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
pub fn insert(&mut self, other: DeadlineFlags)
pub fn insert(&mut self, other: DeadlineFlags)
The bitwise or (|) of the bits in two flags values.
pub fn remove(&mut self, other: DeadlineFlags)
pub fn remove(&mut self, other: DeadlineFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: DeadlineFlags)
pub fn toggle(&mut self, other: DeadlineFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
pub fn set(&mut self, other: DeadlineFlags, value: bool)
pub fn set(&mut self, other: DeadlineFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: DeadlineFlags) -> DeadlineFlags
pub const fn intersection(self, other: DeadlineFlags) -> DeadlineFlags
The bitwise and (&) of the bits in two flags values.
pub const fn union(self, other: DeadlineFlags) -> DeadlineFlags
pub const fn union(self, other: DeadlineFlags) -> DeadlineFlags
The bitwise or (|) of the bits in two flags values.
pub const fn difference(self, other: DeadlineFlags) -> DeadlineFlags
pub const fn difference(self, other: DeadlineFlags) -> DeadlineFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: DeadlineFlags) -> DeadlineFlags
pub const fn symmetric_difference(self, other: DeadlineFlags) -> DeadlineFlags
The bitwise exclusive-or (^) of the bits in two flags values.
pub const fn complement(self) -> DeadlineFlags
pub const fn complement(self) -> DeadlineFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
impl DeadlineFlags
impl DeadlineFlags
pub const fn iter(&self) -> Iter<DeadlineFlags>
pub const fn iter(&self) -> Iter<DeadlineFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<DeadlineFlags>
pub const fn iter_names(&self) -> IterNames<DeadlineFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.