pub struct RayonConfig {
pub cpu_threads: Option<usize>,
pub reserved_cpu_cores: usize,
pub rpc_threads: Option<usize>,
pub storage_threads: Option<usize>,
pub max_blocking_tasks: usize,
pub proof_storage_worker_threads: Option<usize>,
pub proof_account_worker_threads: Option<usize>,
pub prewarming_threads: Option<usize>,
pub bal_streaming_threads: Option<usize>,
}rayon only.Expand description
Configuration for the rayon thread pools.
Fields
cpu_threads: Option<usize>Number of threads for the general CPU pool.
If None, derived from available parallelism minus reserved cores.
reserved_cpu_cores: usizeNumber of CPU cores to reserve for OS and other processes.
rpc_threads: Option<usize>Number of threads for the RPC blocking pool (trace calls, eth_getProof, etc.).
If None, uses the same as cpu_threads.
storage_threads: Option<usize>Number of threads for the storage I/O pool (static file, RocksDB writes in
save_blocks). If None, uses DEFAULT_STORAGE_POOL_THREADS.
max_blocking_tasks: usizeMaximum number of concurrent blocking tasks for the RPC guard semaphore.
proof_storage_worker_threads: Option<usize>Number of threads for the proof storage worker pool (trie storage proof workers).
If None, derived from available parallelism.
proof_account_worker_threads: Option<usize>Number of threads for the proof account worker pool (trie account proof workers).
If None, derived from available parallelism.
prewarming_threads: Option<usize>Number of threads for the prewarming pool (execution prewarming workers).
If None, derived from available parallelism.
bal_streaming_threads: Option<usize>Number of threads for the BAL streaming pool (BAL hashed state streaming).
If None, derived from available parallelism.
Implementations
Sourceimpl RayonConfig
impl RayonConfig
Sourcepub const fn with_reserved_cpu_cores(self, reserved_cpu_cores: usize) -> Self
pub const fn with_reserved_cpu_cores(self, reserved_cpu_cores: usize) -> Self
Set the number of reserved CPU cores.
Sourcepub const fn with_max_blocking_tasks(self, max_blocking_tasks: usize) -> Self
pub const fn with_max_blocking_tasks(self, max_blocking_tasks: usize) -> Self
Set the maximum number of concurrent blocking tasks.
Sourcepub const fn with_rpc_threads(self, rpc_threads: usize) -> Self
pub const fn with_rpc_threads(self, rpc_threads: usize) -> Self
Set the number of threads for the RPC blocking pool.
Sourcepub const fn with_storage_threads(self, storage_threads: usize) -> Self
pub const fn with_storage_threads(self, storage_threads: usize) -> Self
Set the number of threads for the storage I/O pool.
Sourcepub const fn with_proof_storage_worker_threads(
self,
proof_storage_worker_threads: usize,
) -> Self
pub const fn with_proof_storage_worker_threads( self, proof_storage_worker_threads: usize, ) -> Self
Set the number of threads for the proof storage worker pool.
Sourcepub const fn with_proof_account_worker_threads(
self,
proof_account_worker_threads: usize,
) -> Self
pub const fn with_proof_account_worker_threads( self, proof_account_worker_threads: usize, ) -> Self
Set the number of threads for the proof account worker pool.
Sourcepub const fn with_prewarming_threads(self, prewarming_threads: usize) -> Self
pub const fn with_prewarming_threads(self, prewarming_threads: usize) -> Self
Set the number of threads for the prewarming pool.
Sourcepub const fn with_bal_streaming_threads(
self,
bal_streaming_threads: usize,
) -> Self
pub const fn with_bal_streaming_threads( self, bal_streaming_threads: usize, ) -> Self
Set the number of threads for the BAL streaming pool.