Error

Enum Error 

pub enum Error {
    Priority(&'static str),
    PriorityNotInRange(RangeInclusive<i32>),
    OS(i32),
    Ffi(&'static str),
}
A error type

Variants



Priority(&'static str)

A value which describes why it is impossible to use such a priority.



PriorityNotInRange(RangeInclusive<i32>)

Indicates that the priority isn’t in range and it should be within the provided range. This may happen on different operating systems following a single standard of API but allowing different priority values for different scheduling policies.



OS(i32)

Target OS’ error type. In most systems it is an integer which later should be used with target OS’ API for understanding the value. On Linux there is an integer containing an error code from errno. For Windows it contains a number used in Windows for the same purpose.



Ffi(&'static str)

FFI failure.