Struct ThreadBuilder
pub struct ThreadBuilder { /* private fields */ }Expand description
A copy of the std::thread::Builder builder allowing to set priority settings.
use thread_priority::*;
let thread = ThreadBuilder::default()
.name("MyThread")
.priority(ThreadPriority::Max)
.spawn(|result| {
// This is printed out from within the spawned thread.
println!("Set priority result: {:?}", result);
assert!(result.is_ok());
}).unwrap();
thread.join();
// Another example where we don't care about the priority having been set.
let thread = ThreadBuilder::default()
.name("MyThread")
.priority(ThreadPriority::Max)
.spawn_careless(|| {
// This is printed out from within the spawned thread.
println!("We don't care about the priority result.");
}).unwrap();
thread.join();If the compiler version is at least 1.63, the scoped thread support is also enabled.
use thread_priority::*;
// Scoped thread is also supported if the compiler version is at least 1.63.
let mut x = 0;
std::thread::scope(|s|{
let thread = ThreadBuilder::default()
.name("MyThread")
.priority(ThreadPriority::Max)
.spawn_scoped(s, |result| {
// This is printed out from within the spawned thread.
println!("Set priority result: {:?}", result);
assert!(result.is_ok());
x += 1;
}).unwrap();
thread.join();
});
assert_eq!(x, 1);
// Scoped thread also has a "careless" mode.
std::thread::scope(|s|{
let thread = ThreadBuilder::default()
.name("MyThread")
.priority(ThreadPriority::Max)
.spawn_scoped_careless(s, || {
// This is printed out from within the spawned thread.
println!("We don't care about the priority result.");
x += 1;
}).unwrap();
thread.join();
});
assert_eq!(x, 2);Implementations
impl ThreadBuilder
impl ThreadBuilder
pub fn name<VALUE>(self, value: VALUE) -> ThreadBuilder
pub fn name<VALUE>(self, value: VALUE) -> ThreadBuilder
Names the thread-to-be. Currently the name is used for identification only in panic messages.
The name must not contain null bytes (\0).
For more information about named threads, see
std::thread::Builder::name().
pub fn stack_size<VALUE>(self, value: VALUE) -> ThreadBuilder
pub fn stack_size<VALUE>(self, value: VALUE) -> ThreadBuilder
Sets the size of the stack (in bytes) for the new thread.
The actual stack size may be greater than this value if the platform specifies a minimal stack size.
For more information about the stack size for threads, see
std::thread::Builder::stack_size().
pub fn priority<VALUE>(self, value: VALUE) -> ThreadBuilderwhere
VALUE: Into<ThreadPriority>,
pub fn priority<VALUE>(self, value: VALUE) -> ThreadBuilderwhere
VALUE: Into<ThreadPriority>,
The thread’s custom priority.
For more information about the stack size for threads, see
ThreadPriority.
pub fn policy<VALUE>(self, value: VALUE) -> ThreadBuilderwhere
VALUE: Into<ThreadSchedulePolicy>,
Available on Unix only.
pub fn policy<VALUE>(self, value: VALUE) -> ThreadBuilderwhere
VALUE: Into<ThreadSchedulePolicy>,
The thread’s unix scheduling policy.
For more information, see
crate::unix::ThreadSchedulePolicy and crate::unix::set_thread_priority_and_policy.
pub fn spawn<F, T>(self, f: F) -> Result<JoinHandle<T>, Error>
pub fn spawn<F, T>(self, f: F) -> Result<JoinHandle<T>, Error>
Spawns a new thread by taking ownership of the Builder, and returns an
std::io::Result to its std::thread::JoinHandle.
pub fn spawn_scoped<'scope, 'env, F, T>(
self,
scope: &'scope Scope<'scope, 'env>,
f: F,
) -> Result<ScopedJoinHandle<'scope, T>, Error>
pub fn spawn_scoped<'scope, 'env, F, T>( self, scope: &'scope Scope<'scope, 'env>, f: F, ) -> Result<ScopedJoinHandle<'scope, T>, Error>
Spawns a new scoped thread by taking ownership of the Builder, and returns an
std::io::Result to its std::thread::ScopedJoinHandle.
pub fn spawn_careless<F, T>(self, f: F) -> Result<JoinHandle<T>, Error>
pub fn spawn_careless<F, T>(self, f: F) -> Result<JoinHandle<T>, Error>
Spawns a new thread by taking ownership of the Builder, and returns an
std::io::Result to its std::thread::JoinHandle.
pub fn spawn_scoped_careless<'scope, 'env, F, T>(
self,
scope: &'scope Scope<'scope, 'env>,
f: F,
) -> Result<ScopedJoinHandle<'scope, T>, Error>
pub fn spawn_scoped_careless<'scope, 'env, F, T>( self, scope: &'scope Scope<'scope, 'env>, f: F, ) -> Result<ScopedJoinHandle<'scope, T>, Error>
Spawns a new scoped thread by taking ownership of the Builder, and returns an
std::io::Result to its std::thread::ScopedJoinHandle.